@@ -51,12 +51,19 @@ def print_log_header():
     verbose_print("# Command           : %s" % command_line_long())
     verbose_print("# Working Directory : %s" % os.getcwd())
     pbs_jobid = os.environ.get("PBS_JOBID")
+    sge_jobid = os.environ.get("JOB_ID")
+    sge_task_id = os.environ.get("SGE_TASK_ID")
     if pbs_jobid:
-        verbose_print("# $PBS_JOBID        : %s" % pbs_jobid)
+        verbose_print("# Job ID            : %s" % pbs_jobid)
+    elif sge_jobid and sge_task_id:
+        verbose_print("# Job ID            : %s[%s]" % (sge_jobid, sge_task_id))
+    elif sge_jobid:
+        verbose_print("# Job ID            : %s" % sge_jobid)
+
     verbose_print("# Hostname          : %s" % platform.node())
     locale.setlocale(locale.LC_ALL, '')
-    ram_bytes = psutil.virtual_memory().total / 1024 / 1024
-    ram_str = locale.format("%d", ram_bytes, grouping=True)
+    ram_mbytes = psutil.virtual_memory().total / 1024 / 1024
+    ram_str = locale.format("%d", ram_mbytes, grouping=True)
     verbose_print("# RAM               : %s MB" % ram_str)
     verbose_print("# Python Version    : %s" % sys.version.replace("\n", " "))
     verbose_print("")
@@ -265,6 +272,7 @@ def create_snp_matrix(options_dict):
                     'snpListFile':'snplist.txt',
                     'pileupFileName':'reads.snp.pileup',
                     'snpmaFile':'snpma.fasta',
+                    'minConsFreq':0.6,
                    }
     create_snp_matrix(options_dict)
     """
@@ -312,7 +320,7 @@ def create_snp_matrix(options_dict):
 
         sample_name                  = os.path.basename(sample_directory)
         snp_pileup_file_path         = os.path.join(sample_directory, options_dict['pileupFileName'])
-        position_consensus_base_dict = utils.create_consensus_dict(snp_pileup_file_path)
+        position_consensus_base_dict = utils.create_consensus_dict(snp_pileup_file_path, options_dict['minConsFreq'])
         verbose_print("Sample %s consensus base coverage = %.2f%%" % (sample_name, 100.0 * len(position_consensus_base_dict) / snplist_length))
 
         snp_seq_string = ""
